@@ -17,8 +17,7 @@ logger = logging.getLogger(__name__)
 
 def deprecated(replacement=None, message=None, category=FutureWarning):
     """
-    Decorator to mark classes or functions as deprecated,
-    with a possible replacement.
+    Decorator to mark classes or functions as deprecated, with a possible replacement.
 
     Args:
         replacement (callable): A replacement class or method.
@@ -34,25 +33,29 @@ def deprecated(replacement=None, message=None, category=FutureWarning):
         Original function, but with a warning to use the updated class.
     """
 
-    def wrap(old):
+    def craft_message(old, replacement, message):
+        msg = f"{old.__name__} is deprecated"
+        if replacement is not None:
+            if isinstance(replacement, property):
+                r = replacement.fget
+            elif isinstance(replacement, (classmethod, staticmethod)):
+                r = replacement.__func__
+            else:
+                r = replacement
+            msg += f"; use {r.__name__} in {r.__module__} instead."
+        if message is not None:
+            msg += "\n" + message
+        return msg
+
+    def deprecated_decorator(old):
         def wrapped(*args, **kwargs):
-            msg = f"{old.__name__} is deprecated"
-            if replacement is not None:
-                if isinstance(replacement, property):
-                    r = replacement.fget
-                elif isinstance(replacement, (classmethod, staticmethod)):
-                    r = replacement.__func__
-                else:
-                    r = replacement
-                msg += f"; use {r.__name__} in {r.__module__} instead."
-            if message is not None:
-                msg += "\n" + message
+            msg = craft_message(old, replacement, message)
             warnings.warn(msg, category=category, stacklevel=2)
             return old(*args, **kwargs)
 
         return wrapped
 
-    return wrap
+    return deprecated_decorator
 
 
 class requires:
