@@ -2,17 +2,16 @@
 Os functions, e.g., cd, makedirs_p.
 """
 
-import os
 import errno
-
+import os
 from contextlib import contextmanager
 
-__author__ = 'Shyue Ping Ong'
-__copyright__ = 'Copyright 2013, The Materials Project'
-__version__ = '0.1'
-__maintainer__ = 'Shyue Ping Ong'
-__email__ = 'ongsp@ucsd.edu'
-__date__ = '1/24/14'
+__author__ = "Shyue Ping Ong"
+__copyright__ = "Copyright 2013, The Materials Project"
+__version__ = "0.1"
+__maintainer__ = "Shyue Ping Ong"
+__email__ = "ongsp@ucsd.edu"
+__date__ = "1/24/14"
 
 
 @contextmanager
